tiled.client.xarray.DaskVariableClient
======================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DaskVariableClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskVariableClient.__init__
      ~DaskVariableClient.download
      ~DaskVariableClient.export
      ~DaskVariableClient.new_variation
      ~DaskVariableClient.read
      ~DaskVariableClient.read_block
      ~DaskVariableClient.refresh
      ~DaskVariableClient.structure
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskVariableClient.context
      ~DaskVariableClient.data
      ~DaskVariableClient.formats
      ~DaskVariableClient.item
      ~DaskVariableClient.metadata
      ~DaskVariableClient.offline
      ~DaskVariableClient.path
      ~DaskVariableClient.uri
      ~DaskVariableClient.username
   
   